Dir["#{File.dirname(__FILE__)}/../../lib/**/*.rb"].each {|f| require f}

module M3uGen
  class FileMock
    class << self
      def test_dir
        "/tmp/tests/m3ugen"
      end
      def create
        FileUtils.rm_rf test_dir if File.exist? test_dir
        test_files = Marshal.load(File.new("#{File.dirname(__FILE__)}/../../test_data/data.ser", 'r'))

        test_files.each do |file_name|
          dir = File.dirname(file_name)
          FileUtils.mkdir_p dir unless File.exists? dir
          File.open(file_name, "w") {}
        end
      end
    end
  end
end

Given /^no command line parameters$/ do
  @gen = M3uGen::M3uGenerator.new
end

When /^I use the command by default$/ do
  M3uGen::FileMock::create
  File.size(M3uGen::FileMock.test_dir).should be >= 60

  Dir.chdir M3uGen::FileMock::test_dir
end

Then /^it should scan all directories recursively and return a list of files$/ do
  @files = @gen.scan
  @files.size.should == 119
end

Then /^it should save the list within the directory where the command was execute$/ do
  @gen.generate
  File.exist?(Dir.pwd + "/music.m3u").should be true
end

Then /^it should contain filenames with their full path$/ do
  @files = @gen.scan
  @files.inject(true) {|valid, name| valid & name.start_with?(Dir.pwd) }.should be true
end


Then /^it should not generate a m(\d+)u file if we have no music files$/ do |arg1|
  tmp = '/tmp/tests/m3ugen/monkey/'
  Dir.mkdir(tmp)
  Dir.chdir(tmp)

  @gen.generate

  File.exists?(tmp + 'music.m3u').should be false
end

When /^\-r is passed as an option$/ do
  Dir.chdir M3uGen::FileMock::test_dir
  @gen.generate :recursive => true
end

Then /^it should generate one music in each directory recursively$/ do
  @files = @gen.scan
  @files.each do |f|
    File.exist?(File.dirname(f) + File::SEPARATOR + @gen.default_filename).should be true
  end
  File.exist?(Dir.pwd + "/music.m3u").should be true
end
